@@ -82,7 +82,13 @@ def sql(key):
         'ScheduleTaskId1': {'sql':"SELECT id From ScheduleTask ;",'database': 'AnyRobot'},
         'UserId': {'sql':"SELECT userId From User ;",'database': 'AnyRobot'},
         'UserId2': {'sql':"SELECT userId From User ;",'database': 'AnyRobot'},
-        'alertLogId': {'sql':"SELECT alert_scenario_rule_id From RuleEngineAlertLog ;",'database': 'AnyRobot'}
+        'alertLogId': {'sql':"SELECT alert_scenario_rule_id From RuleEngineAlertLog ;",'database': 'AnyRobot'},
+        'RuleEngineEnableId': {'sql':"SELECT id From RuleEngineAlertScenario Where status = 1;",'database': 'AnyRobot'},
+        'RuleEngineDisableId': {'sql':"SELECT id From RuleEngineAlertScenario Where status = 0;",'database': 'AnyRobot'},
+        'KAIAlertEnableId': {'sql':"SELECT id From KAIAlert Where status = 1 ;",'database': 'AnyRobot'},
+        'KAIAlertDisableId': {'sql':"SELECT id From KAIAlert Where status = 0 ;",'database': 'AnyRobot'},
+        'ScheduleTaskEnableId': {'sql':"SELECT id From ScheduleTask Where status = 1 ;",'database': 'AnyRobot'},
+        'ScheduleTaskDisableId': {'sql':"SELECT id From ScheduleTask Where status = 0 ;",'database': 'AnyRobot'}
     }
 
     if switcher.get(key) is not None:
