@@ -4,12 +4,15 @@ from aishu import setting
 from aishu.datafaker.profession.entity import id
 from aishu.datafaker.profession.entity import name,timestamp,zx
 from aishu.public.db_select import select
+import time
 
 
 class search(object):
     def createSearchId(self):
         url = "http://{ip}/v1/search/submit".format(ip=setting.host)
         logGroup = id.date().getDefaultLogGroupID()
+        startTime = timestamp.date().getLastHourTime()
+        endTime = timestamp.date().getEndTime()
         payload = [
             {
                 "logGroup": logGroup,
@@ -25,8 +28,8 @@ class search(object):
                     "must": [
                         {
                             "@timestamp": {
-                                "from": 1441001644796,
-                                "to": 1598854444796
+                                "from": startTime,
+                                "to": endTime
                             }
                         }
                     ],
@@ -138,6 +141,18 @@ class search(object):
 
         return sqldata[0][0]
 
+    # def getContextID(self):
+    #     url = "http://{ip}/v1/search/fetch/{id}".format(ip=setting.host, id=zx.search().createSearchId())
+    #     headers = setting.header
+    #     time.sleep(10)
+    #     rsp = requests.request("GET", url, headers=headers)
+    #     print(rsp)
+    #     ContextID = jsonpath.jsonpath(rsp.json(), '$..{name}'.format(name='_id'))
+    #     if isinstance(ContextID, bool):
+    #         return False
+    #     else:
+    #         return ContextID
+
     # def getOrdinaryID(self):
     #     sql = 'select userId from `User` where loginName!="admin"'
     #     sqldata = select(sql)
@@ -147,10 +162,10 @@ class search(object):
     #     return sqldata[0][0]
 
 if __name__ == '__main__':
-    setting.host = "192.168.84.84"
+    setting.host = "192.168.84.26"
     setting.database = 'AnyRobot'
     setting.password = 'eisoo.com'
     setting.port = 30006
     setting.user = 'root'
-    date = search().getOrdinaryID()
+    date = search().getContextID()
     print(date)
\ No newline at end of file
